Simple Hand tracking game that uses pre programmed pointing gestures to control a block in pygame :
To install :
```bash
pip install hand-tracking

```
```bash
 hand-tracking

```
**AI USED TO REORDER FOLDERS AND TROUBLESHOOT**